#ifndef squid_h
#define squid_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_squid: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_squid */
public:
	MODULE_squid (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context, const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
    /*~PROTOEND~ MODULE_squid */
};

#include "squid.p"

#endif
